==> freebsd-sys-8.2.tar.bz2: sys/dev/lindev/lindev.c <==
/*-
 * Copyright (c) 2009 "Bjoern A. Zeeb" <bz@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * "lindev" is supposed to be a collection of linux-specific devices
 * that we also support, just not by default.
 * While currently there is only "/dev/full", we are planning to see
 * more in the future.
 * This file is only the container to load/unload all supported devices;
 * the implementation of each should go into its own file.
 */

#include <sys/cdefs.h>
__FBSDID("$FreeBSD: src/sys/dev/lindev/lindev.c,v 1.1.2.2.4.1 2010/12/21 17:09:25 kensmith Exp $");

#include <sys/param.h>
#include <sys/conf.h>
#include <sys/kernel.h>
#include <sys/module.h>

#include <dev/lindev/lindev.h>

/* ARGSUSED */
static int
lindev_modevent(module_t mod, int type, void *data)
{
	int error;

	switch(type) {
	case MOD_LOAD:
		error = lindev_modevent_full(mod, type, data);
		break;

	case MOD_UNLOAD:
		error = lindev_modevent_full(mod, type, data);
		break;

	case MOD_SHUTDOWN:
		error = lindev_modevent_full(mod, type, data);
		break;

	default:
		return (EOPNOTSUPP);
	}

	return (error);
}

DEV_MODULE(lindev, lindev_modevent, NULL);
MODULE_VERSION(lindev, 1);

==> freebsd-sys-9.2_rc3.tar.bz2: sys/dev/lindev/lindev.c <==
/*-
 * Copyright (c) 2009 "Bjoern A. Zeeb" <bz@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * "lindev" is supposed to be a collection of linux-specific devices
 * that we also support, just not by default.
 * While currently there is only "/dev/full", we are planning to see
 * more in the future.
 * This file is only the container to load/unload all supported devices;
 * the implementation of each should go into its own file.
 */

#include <sys/cdefs.h>
__FBSDID("$FreeBSD: releng/9.2/sys/dev/lindev/lindev.c 197518 2009-09-26 12:45:28Z bz $");

#include <sys/param.h>
#include <sys/conf.h>
#include <sys/kernel.h>
#include <sys/module.h>

#include <dev/lindev/lindev.h>

/* ARGSUSED */
static int
lindev_modevent(module_t mod, int type, void *data)
{
	int error;

	switch(type) {
	case MOD_LOAD:
		error = lindev_modevent_full(mod, type, data);
		break;

	case MOD_UNLOAD:
		error = lindev_modevent_full(mod, type, data);
		break;

	case MOD_SHUTDOWN:
		error = lindev_modevent_full(mod, type, data);
		break;

	default:
		return (EOPNOTSUPP);
	}

	return (error);
}

DEV_MODULE(lindev, lindev_modevent, NULL);
MODULE_VERSION(lindev, 1);
